// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.flink.sink.writer.serializer;

import java.io.IOException;
import java.io.Serializable;

/**
 * How to serialize the record to bytes.
 *
 * @param <T>
 */
public interface DorisRecordSerializer<T> extends Serializable {

    /**
     * define how to convert record into byte array.
     *
     * @param record
     * @return [tableIdentifer,byte array]
     * @throws IOException
     */
    DorisRecord serialize(T record) throws IOException;

    default void initial() {}

    default DorisRecord flush() {
        return DorisRecord.empty;
    }

    default void close() throws Exception {}
}
